monitor

package
v0.0.0-...-44e29d5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2016 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	// DefaultName is the default name of the complainer instance
	DefaultName = "default"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Monitor

type Monitor struct {
	// contains filtered or unexported fields
}

Monitor is responsible for routing failed tasks to the configured reporters

func NewMonitor

func NewMonitor(name string, cluster *mesos.Cluster, up uploader.Uploader, reporters map[string]reporter.Reporter, defaults bool) *Monitor

NewMonitor creates the new monitor with a name, uploader and reporters

func (*Monitor) ListenAndServe

func (m *Monitor) ListenAndServe(addr string) error

ListenAndServe launches an http server on the requested address. The server is responsible for health checks

func (*Monitor) Run

func (m *Monitor) Run() error

Run does one run across failed tasks and reports any new failures

Jump to